@@ -38,10 +38,10 @@ require_once 'model/AppState.php';
 
 $authscript  = $App->getConfig('EXTERNAL_AUTH','/usr/sbin/benno_auth.d');
 
-$login = $App->getParam('login');
-
-$userid = $login['username'];
-$passwd = $login['password'];
+$login = $App->getParam('login',true);
+$userid = $login['username']; // fetch masked parameter (DB access)
+$passwd = $_REQUEST['login']['password']; // fetch PW raw
+//$passwd = $login['password'];
 
 if (! $passwd) {
     $App->redirect('default',array('MSG'=>'ERR_NOPASS'));
@@ -120,8 +120,9 @@ try {
     $AppState = new AppState($USER->id);
     $searchMaskState = $AppState->getValue('searchMaskState','Simple');
     $App->setSession('searchMaskState',$searchMaskState);
+    $App->setSession('resendMailto',$AppState->getValue('resendMailto'));
 
-    // set current archive
+    // handle deleted archives
     if (!in_array($AppState->getValue('archive'),$archive_list)) {
         $AppState->saveValue('archive','');
     }
