@@ -36,7 +36,6 @@ $BennoUser = new User($data['id']);
 $BennoUser->load();
 
 $BennoUser->name = $data['name'];
-$BennoUser->role = $data['role'];
 
 $EditUser = $App->getSession('EditUser');
 $App->setSession('EditUser','');
@@ -60,8 +59,10 @@ if ($data['password0']) {
     }
 }
 
-if ($USER->getAuthzLevel() >= 16) {
-    // admin users allowed to change adresses
+if ($USER->permission('BNO_ADMIN')) {
+    // admin users allowed to change adress and role
+    $BennoUser->role = $data['role'];
+
     $addresses = array();
     $addrlist = json_decode($data['addresses'],true);
     if ($addrlist) {
@@ -70,6 +71,7 @@ if ($USER->getAuthzLevel() >= 16) {
         }
     }
     $BennoUser->addresses = array_unique($addresses);
+
 }
 
 $BennoUser->save();
