@@ -88,9 +88,9 @@ class License
 
 
     /**
-     * REST build
+     * Number of containers
      */
-    var $restbuild;
+    var $containerCount;
 
 
     /**
@@ -112,7 +112,7 @@ class License
      *
      * @access public
      */
-    function License ($licenseStatus,$licenseExpires,$licenseType,$licenseFile,$address,$hostname,$restbuild,$coreVersion,$restVersion)
+    function License ($licenseStatus,$licenseExpires,$licenseType,$licenseFile,$address,$hostname,$containerCount,$coreVersion,$restVersion)
     {
 
         if (preg_match('/^LICENSE_VALID/',$licenseStatus)) {
@@ -129,9 +129,10 @@ class License
         
         $this->hostname = $this->formatMessage($hostname);
         $this->address =  $this->formatMessage($address);
-        $this->restbuild = $restbuild;
         $this->_licenseFile = $licenseFile;
 
+        // Count - SystemContainer
+        $this->containerCount = --$containerCount;
         $this->coreVersion = $coreVersion;
         $this->restVersion = $restVersion;
 
