@@ -131,8 +131,11 @@ class QueryResult
     }
 
     function numAll () {
+        global $App;
+
         if ($this->overall > 0) {
-            return $this->overall;
+            $App->lang == 'en' ? $tsnd_sep = ',' : $tsnd_sep = '.';
+            return number_format($this->overall,0,'',$tsnd_sep);
         }
         return '';
     }
