@@ -87,11 +87,6 @@ class User extends UserDA
 
 
     /** role
-     *
-     * Authorization level:
-     *     ADMIN    16
-     *     REVISOR   4
-     *     USER      2
      *
      * @access public
      * @var string
@@ -151,11 +146,37 @@ class User extends UserDA
     }
 
     function getAuthzLevel () {
-        if ($this->role == 'ADMIN')   { return 16; }
-        if ($this->role == 'REVISOR') { return 4; }
-        if ($this->role == 'USER')    { return 2; }
+        $level = 0b0;
+
+        // defined in pre_init
+        // BNO_AUTH       2 User authenticated
+        // BNO_USER       4 userpanel (change password)
+        // BNO_SYSINFO    8 Show system information
+        // BNO_SYSDATA   16 SYSDATA container
+        // BNO_ADMIN     32 admingui (change address,role)
+        // BNO_STATS     64 statistics
+        // BNO_SITEADM  128 admingui (change container,siteadmin role)
+
+        if ($this->role == 'AUTH')      { $level = BNO_AUTH            ;}
+        if ($this->role == 'USER')      { $level = BNO_AUTH | BNO_USER ;}
+        if ($this->role == 'REVISOR')   { $level = BNO_AUTH | BNO_SYSINFO | BNO_SYSDATA ;}
+        if ($this->role == 'USERADMIN') { $level = BNO_AUTH |                             BNO_ADMIN ;}
+        if ($this->role == 'ADMIN')     { $level = BNO_AUTH | BNO_SYSINFO | BNO_SYSDATA | BNO_ADMIN | BNO_STATS ;}
+
+        return $level;
     }
 
+
+    function permission($feature) {
+        if (is_string($feature)) {      // 'constant' from Smarty template
+            $feature = constant($feature);
+        }
+        $ret = $feature & $this->getAuthzLevel();
+
+        return $ret;
+    }
+
+
     function setPassword ($pass) { $this->password = password_hash($pass,PASSWORD_BCRYPT); }
 
     function getName () { return $this->name; }
