@@ -243,6 +243,14 @@ class UserDA extends Persistence
             $App->log('WARN '.$e->getMessage(),0);
         }
 
+        // remove SYSDATA
+        $containers = '';
+        foreach ($this->archive as $container) {
+            if ($container == 'SYSDATA') continue;
+            $containers .= $container.',';
+        }
+        $containers = rtrim($containers,',');
+        
         $sql = "DELETE FROM user WHERE id = '$this->id'";
         $res = $DB->query($sql);
         $sql = "INSERT INTO user (id,name,password,archive,role) VALUES (?,?,?,?,?)";
@@ -251,7 +259,7 @@ class UserDA extends Persistence
             $sth->bindValue(1,$this->id);
             $sth->bindValue(2,$this->name);
             $sth->bindValue(3,$this->password);
-            $sth->bindValue(4,@implode($this->archive));
+            $sth->bindValue(4,$containers);
             $sth->bindValue(5,$this->role);
             $res = $sth->execute();
         }
