@@ -43,6 +43,18 @@ $MailObject->bcc        = $EMail->getBcc();
 $MailObject->subject    = $EMail->getSubject();
 $MailObject->verified   = $EMail->isVerified();
 
+if ($App->getConfig('RESEND_MAILTO') == 'last') {
+    $MailObject->resendMailto = $App->getSession('resendMailto');
+}
+else if ($App->getConfig('RESEND_MAILTO') == 'to') {
+    preg_match_all("/[\._a-zA-Z0-9-]+@[\._a-zA-Z0-9-]+/i", $MailObject->to, $addrs);
+    $resendAddr = '';
+    foreach (array_unique($addrs[0]) as $addr) {
+        $resendAddr .= $addr.', ';
+    }
+    $MailObject->resendMailto = rtrim($resendAddr,', ');
+}
+
 if ($USER->role == 'ADMIN') {
     $MailObject->bennoId    = $EMail->bennoId;
 }
