@@ -34,4 +34,8 @@
 $App->assign('interfaceLanguage',$App->getParam('LANG'));
 $App->assign('auth_error',$auth_error);
 
+if ($App->getConfig('ADMIN_FOUREYES')) {
+    $App->assign('ADMIN_FOUREYE',true);
+}
+
 ?>
